import { DocumentReference, DocumentSnapshot, Timestamp } from '@google-cloud/firestore';
/**
 * Read a document with data.
 */
export declare type DocData<A> = Readonly<{
    _tag: 'DocData';
    id: string;
    ref: DocumentReference<A>;
    readTime: Timestamp;
    data: A;
    createTime: Timestamp;
    updateTime: Timestamp;
}>;
/**
 * Read an empty document.
 */
export declare type NoDoc<A> = Readonly<{
    _tag: 'NoDoc';
    id: string;
    ref: DocumentReference<A>;
    readTime: Timestamp;
}>;
/**
 * Document Snapshots either hold data or they don't.
 */
export declare type DocSnap<A> = NoDoc<A> | DocData<A>;
export declare const fromSnapshot: <A>(snap: DocumentSnapshot<A>) => DocSnap<A>;
export declare const fold: <A, B>(onLeft: (f: Readonly<{
    _tag: 'NoDoc';
    id: string;
    ref: DocumentReference<A>;
    readTime: Timestamp;
}>) => B, onRight: (f: Readonly<{
    _tag: 'DocData';
    id: string;
    ref: DocumentReference<A>;
    readTime: Timestamp;
    data: A;
    createTime: Timestamp;
    updateTime: Timestamp;
}>) => B) => (fa: DocSnap<A>) => B;
