import { DocumentReference, Timestamp } from '@google-cloud/firestore';
import * as E from 'fp-ts/Either';
import * as te from './TaggedError';
import { Primitive } from './utils';
import TaggedError = te.TaggedError;
export declare type Sanitized<T> = T extends Timestamp ? Date : T extends DocumentReference ? string : T extends Primitive ? T : T extends ArrayLike<infer U> ? Array<Sanitized<U>> : T extends Record<string, unknown> ? {
    [K in keyof T]: Sanitized<T[K]>;
} : never;
export declare type SanitizationErrorType = 'SanitizationError';
export declare type SanitizationError = TaggedError<SanitizationErrorType>;
export declare const liftSanitizationError: (x: unknown) => SanitizationError;
export declare const sanitize: <A>(data: A) => E.Either<te.TaggedError<"SanitizationError">, Sanitized<A>>;
