import { CollectionReference, DocumentReference, Query, SetOptions, Transaction, WriteResult } from '@google-cloud/firestore';
import * as TE from 'fp-ts/TaskEither';
import { DocSnap } from './DocSnap';
import { FirestoreError } from './FirestoreError';
import { FireDoc } from './utils';
import TaskEither = TE.TaskEither;
export declare const add: <A>(data: FireDoc<A>) => (ref: CollectionReference<A>) => TaskEither<FirestoreError, string>;
export declare const set: <A>(data: FireDoc<A>, setOptions?: SetOptions | undefined) => (ref: DocumentReference<A>) => TaskEither<FirestoreError, WriteResult>;
export declare const update: <A>(data: Partial<FireDoc<A>>) => (ref: DocumentReference<A>) => TaskEither<FirestoreError, WriteResult>;
export declare const create: <A>(data: FireDoc<A>) => (ref: DocumentReference<A>) => TaskEither<FirestoreError, WriteResult>;
export declare const del: <A>(ref: DocumentReference<A>) => TaskEither<FirestoreError, WriteResult>;
export declare const getAll: <A>(query: Query<A>) => TE.TaskEither<FirestoreError, DocSnap<A>[]>;
export declare const get: <A>(ref: DocumentReference<A>) => TE.TaskEither<FirestoreError, DocSnap<A>>;
export declare const getTx: <A>(ref: DocumentReference<A>) => (tx: Transaction) => TE.TaskEither<FirestoreError, DocSnap<A>>;
export declare const getAllTx: <A>(queryOrRefs: Query<A> | DocumentReference<A>[]) => (tx: Transaction) => TE.TaskEither<FirestoreError, DocSnap<A>[]>;
declare type WriteTx = TaskEither<FirestoreError, Transaction>;
export declare const setTx: <A>(data: FireDoc<A>, setOptions?: SetOptions | undefined) => (ref: DocumentReference<A>) => (tx: Transaction) => WriteTx;
export declare const updateTx: <A>(data: Partial<FireDoc<A>>) => (ref: DocumentReference<A>) => (tx: Transaction) => WriteTx;
export declare const createTx: <A>(data: FireDoc<A>) => (ref: DocumentReference<A>) => (tx: Transaction) => WriteTx;
export declare const delTx: <A>(ref: DocumentReference<A>) => (tx: Transaction) => WriteTx;
export {};
