import { CollectionReference, DocumentReference, FieldValue, GeoPoint, Query, Timestamp } from '@google-cloud/firestore';
import * as E from 'fp-ts/Either';
import { Lazy } from 'fp-ts/function';
import * as TE from 'fp-ts/TaskEither';
export declare type Primitive = undefined | null | boolean | string | number;
export declare type FirestoreField = null | boolean | string | number | DocumentReference | FieldValue | Timestamp | GeoPoint | {
    [property: string]: FirestoreField;
} | FirestoreField[];
export declare type FireDoc<A> = {
    [K in keyof A]: FieldValue | A[K];
};
export declare const isObject: (x: unknown) => x is Record<string, unknown>;
export declare const isPrimitive: (x: unknown) => x is Primitive;
export declare const isDate: (x: unknown) => x is Date;
export declare const isTimestamp: (x: unknown) => x is Timestamp;
export declare const isDocumentReference: (x: unknown) => x is DocumentReference<FirebaseFirestore.DocumentData>;
/**
 * Same as fp-ts TaskEither tryCatch but any exceptions thrown by f are caught.
 * @param f a lazy promise that can throw
 * @param onRejected a function used to recover a left value on errors
 */
export declare const taskEitherTryCatch: <Left, Right>(f: Lazy<Promise<Right>>, onRejected: (reason: unknown) => Left) => TE.TaskEither<Left, Right>;
export declare const getOrReject: <L, R>(e: E.Either<L, R>) => R | Promise<never>;
export declare type ExtractReference<T, X> = T extends CollectionReference ? CollectionReference<X> : T extends DocumentReference ? DocumentReference<X> : T extends Query ? Query<X> : never;
export declare type ExtractData<T> = T extends CollectionReference<infer U> ? U : T extends DocumentReference<infer U> ? U : T extends Query<infer U> ? U : never;
